@@ -2,12 +2,12 @@ from arpeggio.cleanpeg import NOT, prefix
 from pulumi.resource import ResourceOptions
 import pulumi_azure_native.resources as resources
 
-def resource_group(stem, props, depends_on=None):
+def resource_group(stem, props, provider=None, parent=None, depends_on=None):
     rg = resources.ResourceGroup(
         f'rg-{stem}',
         resource_group_name=f'rg-{stem}',
         tags=props.tags,
         location=props.location,
-        opts=ResourceOptions(depends_on=depends_on)
+        opts=ResourceOptions(provider=provider, parent=parent, depends_on=depends_on)
     )
     return rg
\ No newline at end of file
